==> mowiki-0.0.1.tar.gz: mowiki/index.php <==
<?php
// MoWiKi: gьWikiN[
// Author: Yuki "Randolph" Okada
// 2004N127 Ƃ肠t@Cۑo悤ɂȂ̂Ń[XB

// gѓƎ̋@\ꂽB
// ƂɂgтŎg₷悤ɁB

// f[^́At@Crawurlencodeꂽy[W^CgȃeLXgt@Cɓ悤B
// XV`FbNmtime悤B

// jFƂ肠Ăl悤B
// ʂɃIuWFNgwłłłB

// Wiki̍\猾āA[œe͖ȁB

// 
$MOWIKI_DATA = 'data/';
$MOWIKI_LIB = 'lib/';
$MOWIKI_VIEW = 'view/';

$MOWIKI_TITLE = 'MoWiKi';
$MOWIKI_ADMIN = 'Randolph';

// 
require($MOWIKI_LIB.'input.php');

// gюʔ
require($MOWIKI_LIB.'carrier.php');

// y[Wꗗ擾(Azzɓ)
// require($MOWIKI_LIB.'content_list.php');

if ($gIn['a'] == 'L') { // ꗗ[h̏ꍇ
  // ꗗƃgbv𓯈ꎋĂB
  // ꗗ=gbvȂAڎwy[Wɍŝ͊yǁAgbvҏWłȂB
  // ꗗ!=gbvȂAgbvҏWł邯ǁAڎwy[Wɍŝ͂߂ǂB
  // Ƃ肠ꗗ=gbvŎĂ݂悤B
  require($MOWIKI_LIB.'content_list.php');

} else if ($gIn['a'] == 'S') { // y[Wۑ[h̏ꍇ
	// f[^ۑ
	require($MOWIKI_LIB.'update.php');

	// y[Wĕ\
	require($MOWIKI_LIB.'render.php');
	$gOut['edit'] = 1;
  
} else if ($gIn['a'] == 'N') { // VK쐬[h̏ꍇ
  
  // y[WƓe͂Ăꍇ
  if ((strlen($gIn['title']) > 0)
	  && (strlen($gIn['body']) > 0)) {

	require($MOWIKI_LIB.'update.php');

  } else if (strlen($gIn['title']) > 0) {
	// y[W͂Ăꍇ

	// e̓tH[\
	require($MOWIKI_LIB.'edit.php');

  } else { // VKy[W쐬tH[\
	require($MOWIKI_LIB.'newpage.php');
  }
  
} else if ($gIn['a'] == 'M') { // ҏW[h̏ꍇ
  // e̓tH[\
  require($MOWIKI_LIB.'edit.php');

} else if ($gIn['a'] == 'D') { // 폜[h̏ꍇ
  // 폜mFhtml\
  
} else { // wy[W\[h̏ꍇ
  if (strlen($gIn['title']) == '0') {
	$gIn['title'] = 'gbv';
  }
  
  // y[W\
  require($MOWIKI_LIB.'render.php');
  $gOut['edit'] = 1;
  
}

require($MOWIKI_VIEW.'template.php');
?>

==> mowiki-0.0.2.tar.gz: mowiki/index.php <==
<?php
// MoWiKi: gьWikiN[
// Author: Yuki "Randolph" Okada
// 2004N127 Ƃ肠t@Cۑo悤ɂȂ̂Ń[XB

// gѓƎ̋@\ꂽB
// ƂɂgтŎg₷悤ɁB

// f[^́At@Crawurlencodeꂽy[W^CgȃeLXgt@Cɓ悤B
// XV`FbNmtime悤B

// jFƂ肠Ăl悤B
// ʂɃIuWFNgwłłłB

// Wiki̍\猾āA[œe͖ȁB

// ݒt@Cǂݍ
require('mowiki-ini.php');

// 
require($MOWIKI_LIB.'input.php');

// gюʔ
require($MOWIKI_LIB.'carrier.php');

// y[Wꗗ擾(Azzɓ)
// require($MOWIKI_LIB.'content_list.php');

if ($gIn['a'] == 'L') { // ꗗ[h̏ꍇ
  // ꗗƃgbv𓯈ꎋĂB
  // ꗗ=gbvȂAڎwy[Wɍŝ͊yǁAgbvҏWłȂB
  // ꗗ!=gbvȂAgbvҏWł邯ǁAڎwy[Wɍŝ͂߂ǂB
  // Ƃ肠ꗗ=gbvŎĂ݂悤B
  require($MOWIKI_LIB.'content_list.php');

} else if ($gIn['a'] == 'S') { // y[Wۑ[h̏ꍇ

  // ͂0oCgȂAt@C폜B
  if (strlen($gIn['body']) == '0') {
	
	$filename = $MOWIKI_DATA.rawurlencode($gIn['title']).'.txt';
	
	if (file_exists($filename)) {
	  unlink($filename);
	}

	require($MOWIKI_LIB.'content_list.php');
	
  } else {
	// f[^ۑ
	require($MOWIKI_LIB.'update.php');

	// y[Wĕ\
	require($MOWIKI_LIB.'render.php');
	$gOut['edit'] = 1;
  }
  
} else if ($gIn['a'] == 'N') { // VK쐬[h̏ꍇ
  
  // y[WƓe͂Ăꍇ
  if ((strlen($gIn['title']) > 0)
	  && (strlen($gIn['body']) > 0)) {

	require($MOWIKI_LIB.'update.php');

  } else if (strlen($gIn['title']) > 0) {
	// y[W͂Ăꍇ

	// e̓tH[\
	require($MOWIKI_LIB.'edit.php');

  } else { // VKy[W쐬tH[\
	require($MOWIKI_LIB.'newpage.php');
  }
  
} else if ($gIn['a'] == 'M') { // ҏW[h̏ꍇ
  // e̓tH[\
  require($MOWIKI_LIB.'edit.php');

} else if ($gIn['a'] == 'D') { // 폜[h̏ꍇ
  // 폜mFhtml\
  
} else { // wy[W\[h̏ꍇ
  if (strlen($gIn['title']) == '0') {
	$gIn['title'] = 'gbv';
  }
  
  // y[W\
  require($MOWIKI_LIB.'render.php');
  $gOut['edit'] = 1;
  
}

require($MOWIKI_VIEW.'template.php');
?>
